.. currentmodule:: pdcast

.. _string_types:

String
======

Generic
-------

.. _string_type:

.. autoclass:: StringType

Python
------

.. _python_string_type:

.. autoclass:: PythonStringType

PyArrow
-------

.. _pyarrow_string_type:

.. autoclass:: PyArrowStringType
